@@ -3,16 +3,16 @@ from jft.directory.remove import f as rmdirie
 from os.path import exists
 
 temp_root = './_dist_tars_remove'
-temp_Λ = list('abc')
+temp_L = list('abc')
 
 def setup(): mkdirine(temp_root)
 def tear_down(): rmdirie(temp_root)
 
 def t():
   setup()
-  f(temp_Λ, temp_root)
-  passed = all([exists(f'{temp_root}/{λ}') for λ in temp_Λ])
+  f(temp_L, temp_root)
+  passed = all([exists(f'{temp_root}/{_l}') for _l in temp_L])
   tear_down()
   return passed
 
-def f(Λ, root='.'): [mkdirine(f'{temp_root}/{λ}') for λ in temp_Λ]
\ No newline at end of file
+def f(_L, root='.'): [mkdirine(f'{temp_root}/{_l}') for _l in temp_L]
\ No newline at end of file
